# hrenpack
#### [README на русском](https://github.com/MagIlyas-DOMA/hrenpack/blob/main/README_RU.md)
#### A universal python library for most tasks.

Divided into several packages:  
`__init__` - basic functions and functions that cannot be assigned to any category  
`boolwork` - working with boolean values  
`classes` - classes  
`clipboard_work` - working with the clipboard  
`cmd` - working with OS tools  
`constants` - various useful constants  
`date_and_time_work` - working with date and time values  
`dbwork` - working with databases. Is in the early stages of development  
`decorators` - decorators  
`dec_to_hex` - working with hexadecimal numbers. It is in early development stages  
`functionwork` - working with functions  
`gpswork` - working with GPS  
`hashwork` - working with hashing  
`encapsulation` - full encapsulation  
`kwargswork` - working with **kwargs  
`listwork` - working with lists, tuples and dictionaries  
`network` - working with the Internet  
`numwork` - working with numbers  
`print_color` - color console. May not work in all consoles  
`resolution` - screen resolution detection  
`slugwork` - work with slug, i.e. with strings that match the rules  
`strwork` - work with strings  
`taskmgr` - work with tasks  
`type_define` - determine whether the data belongs to a certain type or not  
`windows_registry` - work with the Windows registry  

In addition to packages, hrenpack has several sublibraries:    
`custom_methods` - additional methods for existing objects     
`filework` - work with files  
`framework` - additional functions for existing libraries and frameworks  
`office` - work with Microsoft Office files. Is in an early stage of development  

Resources:
The resource folder contains resource files for the correct operation of hrenpack

Usage:
This library is distributed under a 3-clause license BSD

